# **Change log**

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

Changes are grouped into "Added", "Changed", "Deprecated", "Removed", "Fixed", "Security"

## [v0.3.0] - 2019-03-30
### Added
- Added log, changelog and issue files.
- Added support for multiprocessing
- support pypy implementation
- Used deque instead of list to implement queue

### Fixed
- Fixed multiple flake8 issues

### Changed
- Downgrade version from major 1 to 0

## [v0.2.1] - 2019-03-17
### Added
- Added support for python3.7

### Fixed
- Fixed pypi shipping
	
## [v0.2.0] - 2019-01-23 
### Added
- Added setup to publish to PyPi

### Changed
- Re-defined API naming.

## [v0.1.1] - 2018-01-14
### Added
- Added PostgreSQL database support

### Fixed
- Fixed database connection bug

## [v0.1.0] - 2016-11-07
### Changed
- First official release